@@ -105,3 +105,5 @@ class Main():
                         except UserException as e:
                             self.dealUserException(e)
                         print("已成功处理markdown文件", dir)
+        print("所有markdown文档已处理完毕")
+        exit()
